# ChattyCathy
Artificial intelligence (AI) chat bot for Discord written in Python


## Installation

    pip install cathy
    
Or download this package and install with setup.py 

    python setup.py install
    
## Running

    cathy --help
    
## Usage

    Cathy.

    Discord chat bot using AIML artificial intelligence

    Usage:
      cathy <channel> <token>
    
    Options:
      <channel>     Name of channel to chat in
      <token>       Bot's Discord API token
      -h --help     Show this screen.

## Contact

nanodano@devdungeon.com
